alligator 0.7.0 — Alligator 0.8.0-dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- Alligator 0.8.0-dev documentation »

# alligator 0.7.0

date: | 2015-01-01

This release added support for the Beanstalk queue, bringing the supported backends to three!

## Features

- Added Beanstalk support. (SHA:a7edf0c)
- Added docs for the Beanstalk support. (SHA:5c49994)

## Bugfixes

- None

### Navigation

- index
- modules |
- next |
- previous |
- Alligator 0.8.0-dev documentation »